@@ -11,11 +11,11 @@ MMS::Mail::Provider - This provides a default class for parsing an MMS::Mail::Me
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ The following are the top-level methods of the MMS::Mail::Provider class.
 
 =over
 
-=item new()
+=item C<new()>
 
 Return a new MMS::Mail::Provider object.
 
@@ -39,11 +39,11 @@ Return a new MMS::Mail::Provider object.
 
 =over
 
-=item parse MMS::Mail::Message
+=item C<parse> MMS::Mail::Message
 
-The parse method is called as an instance method.  It parses the MMS::Mail::Message and returns an MMS::Mail::Message::Parsed.
+The C<parse> method is called as an instance method.  It parses the MMS::Mail::Message and returns an MMS::Mail::Message::Parsed.
 
-=item retrieve_phone_number STRING
+=item C<retrieve_phone_number> STRING
 
 This method splits the provided string on @ and returns the first list element from the split, replacing any leading + character with 00.  This seems to be the convention used by most UK providers and may work for other providers.
 
@@ -63,7 +63,7 @@ your bug as I make changes.
 
 =head1 NOTES
 
-To quote the perl artistic license ('perldoc perlartistic') :
+Please read the Perl artistic license ('perldoc perlartistic') :
 
 10. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
     WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES
@@ -82,7 +82,7 @@ under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<MMS::Mail::Message>, L<MMS::Mail::Message::Parsed>, L<MMS::Mail::Provider>, L<MMS::Mail::Provider>
+L<MMS::Mail::Message>, L<MMS::Mail::Message::Parsed>, L<MMS::Mail::Provider>
 
 =cut
 
